# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/canbus/proto/transit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/canbus/proto/transit.proto',
  package='apollo.canbus',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"modules/canbus/proto/transit.proto\x12\rapollo.canbus\"Y\n\x14Llc_vehiclelimits_24\x12 \n\x18llc_fbk_maxsteeringangle\x18\x01 \x01(\x05\x12\x1f\n\x17llc_fbk_maxbrakepercent\x18\x02 \x01(\x01\"\x99\x0b\n\x15\x41\x64\x63_motioncontrol1_10\x12\x1f\n\x17\x61\x64\x63_cmd_steerwheelangle\x18\x01 \x01(\x01\x12i\n\x1b\x61\x64\x63_cmd_steeringcontrolmode\x18\x02 \x01(\x0e\x32\x44.apollo.canbus.Adc_motioncontrol1_10.Adc_cmd_steeringcontrolmodeType\x12\x1c\n\x14\x61\x64\x63_cmd_parkingbrake\x18\x03 \x01(\x08\x12K\n\x0c\x61\x64\x63_cmd_gear\x18\x04 \x01(\x0e\x32\x35.apollo.canbus.Adc_motioncontrol1_10.Adc_cmd_gearType\x12#\n\x1b\x61\x64\x63_motioncontrol1_checksum\x18\x05 \x01(\x05\x12\x1f\n\x17\x61\x64\x63_cmd_brakepercentage\x18\x06 \x01(\x01\x12 \n\x18\x61\x64\x63_cmd_throttleposition\x18\x07 \x01(\x01\x12\"\n\x1a\x61\x64\x63_motioncontrol1_counter\x18\x08 \x01(\x05\x12\x61\n\x17\x61\x64\x63_cmd_autonomyrequest\x18\t \x01(\x0e\x32@.apollo.canbus.Adc_motioncontrol1_10.Adc_cmd_autonomyrequestType\x12q\n\x1f\x61\x64\x63_cmd_longitudinalcontrolmode\x18\n \x01(\x0e\x32H.apollo.canbus.Adc_motioncontrol1_10.Adc_cmd_longitudinalcontrolmodeType\"\xcc\x01\n\x1f\x41\x64\x63_cmd_steeringcontrolmodeType\x12$\n ADC_CMD_STEERINGCONTROLMODE_NONE\x10\x00\x12%\n!ADC_CMD_STEERINGCONTROLMODE_ANGLE\x10\x01\x12\x32\n.ADC_CMD_STEERINGCONTROLMODE_RESERVED_CURVATURE\x10\x02\x12(\n$ADC_CMD_STEERINGCONTROLMODE_RESERVED\x10\x03\"}\n\x10\x41\x64\x63_cmd_gearType\x12\x17\n\x13\x41\x44\x43_CMD_GEAR_P_PARK\x10\x00\x12\x18\n\x14\x41\x44\x43_CMD_GEAR_D_DRIVE\x10\x01\x12\x1a\n\x16\x41\x44\x43_CMD_GEAR_N_NEUTRAL\x10\x02\x12\x1a\n\x16\x41\x44\x43_CMD_GEAR_R_REVERSE\x10\x03\"\xcf\x01\n\x1b\x41\x64\x63_cmd_autonomyrequestType\x12\x32\n.ADC_CMD_AUTONOMYREQUEST_AUTONOMY_NOT_REQUESTED\x10\x00\x12.\n*ADC_CMD_AUTONOMYREQUEST_AUTONOMY_REQUESTED\x10\x01\x12%\n!ADC_CMD_AUTONOMYREQUEST_RESERVED0\x10\x02\x12%\n!ADC_CMD_AUTONOMYREQUEST_RESERVED1\x10\x03\"\x86\x02\n#Adc_cmd_longitudinalcontrolmodeType\x12(\n$ADC_CMD_LONGITUDINALCONTROLMODE_NONE\x10\x00\x12\x46\nBADC_CMD_LONGITUDINALCONTROLMODE_RESERVED_VELOCITY_AND_ACCELERATION\x10\x01\x12\x32\n.ADC_CMD_LONGITUDINALCONTROLMODE_RESERVED_FORCE\x10\x02\x12\x39\n5ADC_CMD_LONGITUDINALCONTROLMODE_DIRECT_THROTTLE_BRAKE\x10\x03\"\x87\x01\n\x1b\x41\x64\x63_motioncontrollimits1_12\x12$\n\x1c\x61\x64\x63_cmd_throttlecommandlimit\x18\x01 \x01(\x01\x12\x1c\n\x14\x61\x64\x63_cmd_steeringrate\x18\x02 \x01(\x01\x12$\n\x1c\x61\x64\x63_cmd_steerwheelanglelimit\x18\x03 \x01(\x01\"\xc5\x0e\n\x16Llc_motionfeedback1_20\x12L\n\x0cllc_fbk_gear\x18\x01 \x01(\x0e\x32\x36.apollo.canbus.Llc_motionfeedback1_20.Llc_fbk_gearType\x12\x1c\n\x14llc_fbk_parkingbrake\x18\x02 \x01(\x08\x12 \n\x18llc_fbk_throttleposition\x18\x03 \x01(\x01\x12 \n\x18llc_fbk_brakepercentrear\x18\x04 \x01(\x01\x12!\n\x19llc_fbk_brakepercentfront\x18\x05 \x01(\x01\x12j\n\x1bllc_fbk_steeringcontrolmode\x18\x06 \x01(\x0e\x32\x45.apollo.canbus.Llc_motionfeedback1_20.Llc_fbk_steeringcontrolmodeType\x12#\n\x1bllc_motionfeedback1_counter\x18\x07 \x01(\x05\x12$\n\x1cllc_motionfeedback1_checksum\x18\x08 \x01(\x05\x12\x1e\n\x16llc_fbk_commandaligned\x18\t \x01(\x08\x12\x1c\n\x14llc_fbk_estoppressed\x18\n \x01(\x08\x12\"\n\x1allc_fbk_adcrequestautonomy\x18\x0b \x01(\x08\x12\x1d\n\x15llc_fbk_allowautonomy\x18\x0c \x01(\x08\x12r\n\x1fllc_fbk_longitudinalcontrolmode\x18\r \x01(\x0e\x32I.apollo.canbus.Llc_motionfeedback1_20.Llc_fbk_longitudinalcontrolmodeType\x12N\n\rllc_fbk_state\x18\x0e \x01(\x0e\x32\x37.apollo.canbus.Llc_motionfeedback1_20.Llc_fbk_stateType\"}\n\x10Llc_fbk_gearType\x12\x17\n\x13LLC_FBK_GEAR_P_PARK\x10\x00\x12\x18\n\x14LLC_FBK_GEAR_D_DRIVE\x10\x01\x12\x1a\n\x16LLC_FBK_GEAR_N_NEUTRAL\x10\x02\x12\x1a\n\x16LLC_FBK_GEAR_R_REVERSE\x10\x03\"\xcc\x01\n\x1fLlc_fbk_steeringcontrolmodeType\x12$\n LLC_FBK_STEERINGCONTROLMODE_NONE\x10\x00\x12%\n!LLC_FBK_STEERINGCONTROLMODE_ANGLE\x10\x01\x12\x32\n.LLC_FBK_STEERINGCONTROLMODE_RESERVED_CURVATURE\x10\x02\x12(\n$LLC_FBK_STEERINGCONTROLMODE_RESERVED\x10\x03\"\x86\x02\n#Llc_fbk_longitudinalcontrolmodeType\x12(\n$LLC_FBK_LONGITUDINALCONTROLMODE_NONE\x10\x00\x12\x46\nBLLC_FBK_LONGITUDINALCONTROLMODE_RESERVED_VELOCITY_AND_ACCELERATION\x10\x01\x12\x32\n.LLC_FBK_LONGITUDINALCONTROLMODE_RESERVED_FORCE\x10\x02\x12\x39\n5LLC_FBK_LONGITUDINALCONTROLMODE_DIRECT_THROTTLE_BRAKE\x10\x03\"\x84\x04\n\x11Llc_fbk_stateType\x12\x1b\n\x17LLC_FBK_STATE_RESERVED0\x10\x00\x12&\n\"LLC_FBK_STATE_AUTONOMY_NOT_ALLOWED\x10\x01\x12\"\n\x1eLLC_FBK_STATE_AUTONOMY_ALLOWED\x10\x02\x12$\n LLC_FBK_STATE_AUTONOMY_REQUESTED\x10\x03\x12\x1a\n\x16LLC_FBK_STATE_AUTONOMY\x10\x04\x12\x1b\n\x17LLC_FBK_STATE_RESERVED1\x10\x05\x12\x1b\n\x17LLC_FBK_STATE_RESERVED2\x10\x06\x12\x1b\n\x17LLC_FBK_STATE_RESERVED3\x10\x07\x12\x1b\n\x17LLC_FBK_STATE_RESERVED4\x10\x08\x12\x1b\n\x17LLC_FBK_STATE_RESERVED5\x10\t\x12\x1b\n\x17LLC_FBK_STATE_RESERVED6\x10\n\x12\x1b\n\x17LLC_FBK_STATE_RESERVED7\x10\x0b\x12\x1b\n\x17LLC_FBK_STATE_RESERVED8\x10\x0c\x12%\n!LLC_FBK_STATE_DISENGAGE_REQUESTED\x10\r\x12\x1c\n\x18LLC_FBK_STATE_DISENGAGED\x10\x0e\x12\x17\n\x13LLC_FBK_STATE_FAULT\x10\x0f\"\xbe\x01\n\x16Llc_motionfeedback2_21\x12\x1c\n\x14llc_fbk_vehiclespeed\x18\x01 \x01(\x01\x12#\n\x1bllc_motionfeedback2_counter\x18\x02 \x01(\x05\x12$\n\x1cllc_motionfeedback2_checksum\x18\x03 \x01(\x05\x12\x1c\n\x14llc_fbk_steeringrate\x18\x04 \x01(\x01\x12\x1d\n\x15llc_fbk_steeringangle\x18\x05 \x01(\x01\"\xe2\x01\n\x1dLlc_motioncommandfeedback1_22\x12%\n\x1dllc_fbk_steeringanglesetpoint\x18\x01 \x01(\x01\x12 \n\x18llc_fbk_throttlesetpoint\x18\x02 \x01(\x01\x12$\n\x1cllc_fbk_brakepercentsetpoint\x18\x03 \x01(\x01\x12(\n llc_motioncommandfeedback1_count\x18\x04 \x01(\x05\x12(\n llc_motioncommandfeedback1_check\x18\x05 \x01(\x05\"1\n\x14Llc_vehiclestatus_25\x12\x19\n\x11llc_fbk_12voltage\x18\x01 \x01(\x01\"\xcb\x05\n\x19Llc_auxiliaryfeedback_120\x12\x18\n\x10llc_fbk_inverter\x18\x01 \x01(\x08\x12\x17\n\x0fllc_fbk_pdu_ch8\x18\x02 \x01(\x08\x12\x17\n\x0fllc_fbk_pdu_ch7\x18\x03 \x01(\x08\x12\x17\n\x0fllc_fbk_pdu_ch6\x18\x04 \x01(\x08\x12\x17\n\x0fllc_fbk_pdu_ch5\x18\x05 \x01(\x08\x12\x17\n\x0fllc_fbk_pdu_ch4\x18\x06 \x01(\x08\x12\x17\n\x0fllc_fbk_pdu_ch3\x18\x07 \x01(\x08\x12\x17\n\x0fllc_fbk_pdu_ch2\x18\x08 \x01(\x08\x12\x17\n\x0fllc_fbk_pdu_ch1\x18\t \x01(\x08\x12\x1c\n\x14llc_fbk_hazardlights\x18\n \x01(\x08\x12\x1a\n\x12llc_fbk_ledgreenon\x18\x0b \x01(\x08\x12\x14\n\x0cllc_fbk_horn\x18\x0c \x01(\x08\x12\x18\n\x10llc_fbk_buzzeron\x18\r \x01(\x08\x12[\n\x12llc_fbk_turnsignal\x18\x0e \x01(\x0e\x32?.apollo.canbus.Llc_auxiliaryfeedback_120.Llc_fbk_turnsignalType\x12\x17\n\x0fllc_fbk_lowbeam\x18\x0f \x01(\x08\x12\x18\n\x10llc_fbk_highbeam\x18\x10 \x01(\x08\x12\x18\n\x10llc_fbk_ledredon\x18\x11 \x01(\x08\x12%\n\x1dllc_fbk_autonomybuttonpressed\x18\x12 \x01(\x08\"\x90\x01\n\x16Llc_fbk_turnsignalType\x12\x1b\n\x17LLC_FBK_TURNSIGNAL_NONE\x10\x00\x12\x1b\n\x17LLC_FBK_TURNSIGNAL_LEFT\x10\x01\x12\x1c\n\x18LLC_FBK_TURNSIGNAL_RIGHT\x10\x02\x12\x1e\n\x1aLLC_FBK_TURNSIGNAL_RESERVE\x10\x03\"\xbe\x02\n\x12Llc_diag_fault_620\x12\"\n\x1allc_disengagecounter_brake\x18\x01 \x01(\x05\x12\"\n\x1allc_disengagecounter_steer\x18\x02 \x01(\x05\x12%\n\x1dllc_disengagecounter_throttle\x18\x03 \x01(\x05\x12\x1c\n\x14llc_fbk_faultcounter\x18\x04 \x01(\x05\x12#\n\x1bllc_disengagecounter_button\x18\x05 \x01(\x05\x12\x1c\n\x14llc_fbk_version_year\x18\x06 \x01(\x05\x12\x1d\n\x15llc_fbk_version_month\x18\x07 \x01(\x05\x12\x1b\n\x13llc_fbk_version_day\x18\x08 \x01(\x05\x12\x1c\n\x14llc_fbk_version_hour\x18\t \x01(\x05\"\x96\x01\n\x1cLlc_diag_steeringcontrol_722\x12&\n\x1ellc_dbg_steeringsensorposition\x18\x01 \x01(\x01\x12\'\n\x1fllc_dbg_steeringrackinputtorque\x18\x02 \x01(\x05\x12%\n\x1dllc_dbg_steeringmotorposition\x18\x03 \x01(\x01\"\xf5\x05\n\x18\x41\x64\x63_auxiliarycontrol_110\x12\x1e\n\x16\x61\x64\x63_auxcontrol_counter\x18\x01 \x01(\x05\x12\x1f\n\x17\x61\x64\x63_auxcontrol_checksum\x18\x02 \x01(\x05\x12&\n\x1e\x61\x64\x63_cmd_inverter_controlenable\x18\x03 \x01(\x08\x12\x18\n\x10\x61\x64\x63_cmd_inverter\x18\x04 \x01(\x08\x12\x15\n\radc_cmd_wiper\x18\x05 \x01(\x05\x12!\n\x19\x61\x64\x63_cmd_pdu_controlenable\x18\x06 \x01(\x08\x12\x17\n\x0f\x61\x64\x63_cmd_pdu_ch8\x18\x07 \x01(\x08\x12\x17\n\x0f\x61\x64\x63_cmd_pdu_ch7\x18\x08 \x01(\x08\x12\x17\n\x0f\x61\x64\x63_cmd_pdu_ch6\x18\t \x01(\x08\x12\x17\n\x0f\x61\x64\x63_cmd_pdu_ch5\x18\n \x01(\x08\x12\x17\n\x0f\x61\x64\x63_cmd_pdu_ch4\x18\x0b \x01(\x08\x12\x17\n\x0f\x61\x64\x63_cmd_pdu_ch3\x18\x0c \x01(\x08\x12\x17\n\x0f\x61\x64\x63_cmd_pdu_ch2\x18\r \x01(\x08\x12\x17\n\x0f\x61\x64\x63_cmd_pdu_ch1\x18\x0e \x01(\x08\x12\x1c\n\x14\x61\x64\x63_cmd_hazardlights\x18\x0f \x01(\x08\x12\x18\n\x10\x61\x64\x63_cmd_highbeam\x18\x10 \x01(\x08\x12\x17\n\x0f\x61\x64\x63_cmd_lowbeam\x18\x11 \x01(\x08\x12\x14\n\x0c\x61\x64\x63_cmd_horn\x18\x12 \x01(\x08\x12Z\n\x12\x61\x64\x63_cmd_turnsignal\x18\x13 \x01(\x0e\x32>.apollo.canbus.Adc_auxiliarycontrol_110.Adc_cmd_turnsignalType\"\x90\x01\n\x16\x41\x64\x63_cmd_turnsignalType\x12\x1b\n\x17\x41\x44\x43_CMD_TURNSIGNAL_NONE\x10\x00\x12\x1b\n\x17\x41\x44\x43_CMD_TURNSIGNAL_LEFT\x10\x01\x12\x1c\n\x18\x41\x44\x43_CMD_TURNSIGNAL_RIGHT\x10\x02\x12\x1e\n\x1a\x41\x44\x43_CMD_TURNSIGNAL_RESERVE\x10\x03\"\xf6\x01\n\x19Llc_diag_brakecontrol_721\x12&\n\x1ellc_dbg_brakepidcontribution_p\x18\x01 \x01(\x01\x12&\n\x1ellc_dbg_brakepidcontribution_i\x18\x02 \x01(\x01\x12&\n\x1ellc_dbg_brakepidcontribution_d\x18\x03 \x01(\x01\x12\x1f\n\x17llc_dbg_brakepid_output\x18\x04 \x01(\x01\x12\x1e\n\x16llc_dbg_brakepid_error\x18\x05 \x01(\x05\x12 \n\x18llc_dbg_brakefeedforward\x18\x06 \x01(\x01\"\xff\x06\n\x07Transit\x12\x41\n\x14llc_vehiclelimits_24\x18\x01 \x01(\x0b\x32#.apollo.canbus.Llc_vehiclelimits_24\x12\x43\n\x15\x61\x64\x63_motioncontrol1_10\x18\x02 \x01(\x0b\x32$.apollo.canbus.Adc_motioncontrol1_10\x12O\n\x1b\x61\x64\x63_motioncontrollimits1_12\x18\x03 \x01(\x0b\x32*.apollo.canbus.Adc_motioncontrollimits1_12\x12\x45\n\x16llc_motionfeedback1_20\x18\x04 \x01(\x0b\x32%.apollo.canbus.Llc_motionfeedback1_20\x12\x45\n\x16llc_motionfeedback2_21\x18\x05 \x01(\x0b\x32%.apollo.canbus.Llc_motionfeedback2_21\x12S\n\x1dllc_motioncommandfeedback1_22\x18\x06 \x01(\x0b\x32,.apollo.canbus.Llc_motioncommandfeedback1_22\x12\x41\n\x14llc_vehiclestatus_25\x18\x07 \x01(\x0b\x32#.apollo.canbus.Llc_vehiclestatus_25\x12K\n\x19llc_auxiliaryfeedback_120\x18\x08 \x01(\x0b\x32(.apollo.canbus.Llc_auxiliaryfeedback_120\x12=\n\x12llc_diag_fault_620\x18\t \x01(\x0b\x32!.apollo.canbus.Llc_diag_fault_620\x12Q\n\x1cllc_diag_steeringcontrol_722\x18\n \x01(\x0b\x32+.apollo.canbus.Llc_diag_steeringcontrol_722\x12I\n\x18\x61\x64\x63_auxiliarycontrol_110\x18\x0b \x01(\x0b\x32\'.apollo.canbus.Adc_auxiliarycontrol_110\x12K\n\x19llc_diag_brakecontrol_721\x18\x0c \x01(\x0b\x32(.apollo.canbus.Llc_diag_brakecontrol_721'
)



_ADC_MOTIONCONTROL1_10_ADC_CMD_STEERINGCONTROLMODETYPE = _descriptor.EnumDescriptor(
  name='Adc_cmd_steeringcontrolmodeType',
  full_name='apollo.canbus.Adc_motioncontrol1_10.Adc_cmd_steeringcontrolmodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_STEERINGCONTROLMODE_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_STEERINGCONTROLMODE_ANGLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_STEERINGCONTROLMODE_RESERVED_CURVATURE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_STEERINGCONTROLMODE_RESERVED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=772,
  serialized_end=976,
)
_sym_db.RegisterEnumDescriptor(_ADC_MOTIONCONTROL1_10_ADC_CMD_STEERINGCONTROLMODETYPE)

_ADC_MOTIONCONTROL1_10_ADC_CMD_GEARTYPE = _descriptor.EnumDescriptor(
  name='Adc_cmd_gearType',
  full_name='apollo.canbus.Adc_motioncontrol1_10.Adc_cmd_gearType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_GEAR_P_PARK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_GEAR_D_DRIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_GEAR_N_NEUTRAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_GEAR_R_REVERSE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=978,
  serialized_end=1103,
)
_sym_db.RegisterEnumDescriptor(_ADC_MOTIONCONTROL1_10_ADC_CMD_GEARTYPE)

_ADC_MOTIONCONTROL1_10_ADC_CMD_AUTONOMYREQUESTTYPE = _descriptor.EnumDescriptor(
  name='Adc_cmd_autonomyrequestType',
  full_name='apollo.canbus.Adc_motioncontrol1_10.Adc_cmd_autonomyrequestType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_AUTONOMYREQUEST_AUTONOMY_NOT_REQUESTED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_AUTONOMYREQUEST_AUTONOMY_REQUESTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_AUTONOMYREQUEST_RESERVED0', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_AUTONOMYREQUEST_RESERVED1', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1106,
  serialized_end=1313,
)
_sym_db.RegisterEnumDescriptor(_ADC_MOTIONCONTROL1_10_ADC_CMD_AUTONOMYREQUESTTYPE)

_ADC_MOTIONCONTROL1_10_ADC_CMD_LONGITUDINALCONTROLMODETYPE = _descriptor.EnumDescriptor(
  name='Adc_cmd_longitudinalcontrolmodeType',
  full_name='apollo.canbus.Adc_motioncontrol1_10.Adc_cmd_longitudinalcontrolmodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_LONGITUDINALCONTROLMODE_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_LONGITUDINALCONTROLMODE_RESERVED_VELOCITY_AND_ACCELERATION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_LONGITUDINALCONTROLMODE_RESERVED_FORCE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_LONGITUDINALCONTROLMODE_DIRECT_THROTTLE_BRAKE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1316,
  serialized_end=1578,
)
_sym_db.RegisterEnumDescriptor(_ADC_MOTIONCONTROL1_10_ADC_CMD_LONGITUDINALCONTROLMODETYPE)

_LLC_MOTIONFEEDBACK1_20_LLC_FBK_GEARTYPE = _descriptor.EnumDescriptor(
  name='Llc_fbk_gearType',
  full_name='apollo.canbus.Llc_motionfeedback1_20.Llc_fbk_gearType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_GEAR_P_PARK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_GEAR_D_DRIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_GEAR_N_NEUTRAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_GEAR_R_REVERSE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2464,
  serialized_end=2589,
)
_sym_db.RegisterEnumDescriptor(_LLC_MOTIONFEEDBACK1_20_LLC_FBK_GEARTYPE)

_LLC_MOTIONFEEDBACK1_20_LLC_FBK_STEERINGCONTROLMODETYPE = _descriptor.EnumDescriptor(
  name='Llc_fbk_steeringcontrolmodeType',
  full_name='apollo.canbus.Llc_motionfeedback1_20.Llc_fbk_steeringcontrolmodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STEERINGCONTROLMODE_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STEERINGCONTROLMODE_ANGLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STEERINGCONTROLMODE_RESERVED_CURVATURE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STEERINGCONTROLMODE_RESERVED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2592,
  serialized_end=2796,
)
_sym_db.RegisterEnumDescriptor(_LLC_MOTIONFEEDBACK1_20_LLC_FBK_STEERINGCONTROLMODETYPE)

_LLC_MOTIONFEEDBACK1_20_LLC_FBK_LONGITUDINALCONTROLMODETYPE = _descriptor.EnumDescriptor(
  name='Llc_fbk_longitudinalcontrolmodeType',
  full_name='apollo.canbus.Llc_motionfeedback1_20.Llc_fbk_longitudinalcontrolmodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_LONGITUDINALCONTROLMODE_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_LONGITUDINALCONTROLMODE_RESERVED_VELOCITY_AND_ACCELERATION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_LONGITUDINALCONTROLMODE_RESERVED_FORCE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_LONGITUDINALCONTROLMODE_DIRECT_THROTTLE_BRAKE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2799,
  serialized_end=3061,
)
_sym_db.RegisterEnumDescriptor(_LLC_MOTIONFEEDBACK1_20_LLC_FBK_LONGITUDINALCONTROLMODETYPE)

_LLC_MOTIONFEEDBACK1_20_LLC_FBK_STATETYPE = _descriptor.EnumDescriptor(
  name='Llc_fbk_stateType',
  full_name='apollo.canbus.Llc_motionfeedback1_20.Llc_fbk_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_RESERVED0', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_AUTONOMY_NOT_ALLOWED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_AUTONOMY_ALLOWED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_AUTONOMY_REQUESTED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_AUTONOMY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_RESERVED1', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_RESERVED2', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_RESERVED3', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_RESERVED4', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_RESERVED5', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_RESERVED6', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_RESERVED7', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_RESERVED8', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_DISENGAGE_REQUESTED', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_DISENGAGED', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_STATE_FAULT', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3064,
  serialized_end=3580,
)
_sym_db.RegisterEnumDescriptor(_LLC_MOTIONFEEDBACK1_20_LLC_FBK_STATETYPE)

_LLC_AUXILIARYFEEDBACK_120_LLC_FBK_TURNSIGNALTYPE = _descriptor.EnumDescriptor(
  name='Llc_fbk_turnsignalType',
  full_name='apollo.canbus.Llc_auxiliaryfeedback_120.Llc_fbk_turnsignalType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_TURNSIGNAL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_TURNSIGNAL_LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_TURNSIGNAL_RIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LLC_FBK_TURNSIGNAL_RESERVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4627,
  serialized_end=4771,
)
_sym_db.RegisterEnumDescriptor(_LLC_AUXILIARYFEEDBACK_120_LLC_FBK_TURNSIGNALTYPE)

_ADC_AUXILIARYCONTROL_110_ADC_CMD_TURNSIGNALTYPE = _descriptor.EnumDescriptor(
  name='Adc_cmd_turnsignalType',
  full_name='apollo.canbus.Adc_auxiliarycontrol_110.Adc_cmd_turnsignalType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_TURNSIGNAL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_TURNSIGNAL_LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_TURNSIGNAL_RIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADC_CMD_TURNSIGNAL_RESERVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5861,
  serialized_end=6005,
)
_sym_db.RegisterEnumDescriptor(_ADC_AUXILIARYCONTROL_110_ADC_CMD_TURNSIGNALTYPE)


_LLC_VEHICLELIMITS_24 = _descriptor.Descriptor(
  name='Llc_vehiclelimits_24',
  full_name='apollo.canbus.Llc_vehiclelimits_24',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='llc_fbk_maxsteeringangle', full_name='apollo.canbus.Llc_vehiclelimits_24.llc_fbk_maxsteeringangle', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_maxbrakepercent', full_name='apollo.canbus.Llc_vehiclelimits_24.llc_fbk_maxbrakepercent', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=142,
)


_ADC_MOTIONCONTROL1_10 = _descriptor.Descriptor(
  name='Adc_motioncontrol1_10',
  full_name='apollo.canbus.Adc_motioncontrol1_10',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='adc_cmd_steerwheelangle', full_name='apollo.canbus.Adc_motioncontrol1_10.adc_cmd_steerwheelangle', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_steeringcontrolmode', full_name='apollo.canbus.Adc_motioncontrol1_10.adc_cmd_steeringcontrolmode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_parkingbrake', full_name='apollo.canbus.Adc_motioncontrol1_10.adc_cmd_parkingbrake', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_gear', full_name='apollo.canbus.Adc_motioncontrol1_10.adc_cmd_gear', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_motioncontrol1_checksum', full_name='apollo.canbus.Adc_motioncontrol1_10.adc_motioncontrol1_checksum', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_brakepercentage', full_name='apollo.canbus.Adc_motioncontrol1_10.adc_cmd_brakepercentage', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_throttleposition', full_name='apollo.canbus.Adc_motioncontrol1_10.adc_cmd_throttleposition', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_motioncontrol1_counter', full_name='apollo.canbus.Adc_motioncontrol1_10.adc_motioncontrol1_counter', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_autonomyrequest', full_name='apollo.canbus.Adc_motioncontrol1_10.adc_cmd_autonomyrequest', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_longitudinalcontrolmode', full_name='apollo.canbus.Adc_motioncontrol1_10.adc_cmd_longitudinalcontrolmode', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADC_MOTIONCONTROL1_10_ADC_CMD_STEERINGCONTROLMODETYPE,
    _ADC_MOTIONCONTROL1_10_ADC_CMD_GEARTYPE,
    _ADC_MOTIONCONTROL1_10_ADC_CMD_AUTONOMYREQUESTTYPE,
    _ADC_MOTIONCONTROL1_10_ADC_CMD_LONGITUDINALCONTROLMODETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=1578,
)


_ADC_MOTIONCONTROLLIMITS1_12 = _descriptor.Descriptor(
  name='Adc_motioncontrollimits1_12',
  full_name='apollo.canbus.Adc_motioncontrollimits1_12',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='adc_cmd_throttlecommandlimit', full_name='apollo.canbus.Adc_motioncontrollimits1_12.adc_cmd_throttlecommandlimit', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_steeringrate', full_name='apollo.canbus.Adc_motioncontrollimits1_12.adc_cmd_steeringrate', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_steerwheelanglelimit', full_name='apollo.canbus.Adc_motioncontrollimits1_12.adc_cmd_steerwheelanglelimit', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1581,
  serialized_end=1716,
)


_LLC_MOTIONFEEDBACK1_20 = _descriptor.Descriptor(
  name='Llc_motionfeedback1_20',
  full_name='apollo.canbus.Llc_motionfeedback1_20',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='llc_fbk_gear', full_name='apollo.canbus.Llc_motionfeedback1_20.llc_fbk_gear', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_parkingbrake', full_name='apollo.canbus.Llc_motionfeedback1_20.llc_fbk_parkingbrake', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_throttleposition', full_name='apollo.canbus.Llc_motionfeedback1_20.llc_fbk_throttleposition', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_brakepercentrear', full_name='apollo.canbus.Llc_motionfeedback1_20.llc_fbk_brakepercentrear', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_brakepercentfront', full_name='apollo.canbus.Llc_motionfeedback1_20.llc_fbk_brakepercentfront', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_steeringcontrolmode', full_name='apollo.canbus.Llc_motionfeedback1_20.llc_fbk_steeringcontrolmode', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_motionfeedback1_counter', full_name='apollo.canbus.Llc_motionfeedback1_20.llc_motionfeedback1_counter', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_motionfeedback1_checksum', full_name='apollo.canbus.Llc_motionfeedback1_20.llc_motionfeedback1_checksum', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_commandaligned', full_name='apollo.canbus.Llc_motionfeedback1_20.llc_fbk_commandaligned', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_estoppressed', full_name='apollo.canbus.Llc_motionfeedback1_20.llc_fbk_estoppressed', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_adcrequestautonomy', full_name='apollo.canbus.Llc_motionfeedback1_20.llc_fbk_adcrequestautonomy', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_allowautonomy', full_name='apollo.canbus.Llc_motionfeedback1_20.llc_fbk_allowautonomy', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_longitudinalcontrolmode', full_name='apollo.canbus.Llc_motionfeedback1_20.llc_fbk_longitudinalcontrolmode', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_state', full_name='apollo.canbus.Llc_motionfeedback1_20.llc_fbk_state', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LLC_MOTIONFEEDBACK1_20_LLC_FBK_GEARTYPE,
    _LLC_MOTIONFEEDBACK1_20_LLC_FBK_STEERINGCONTROLMODETYPE,
    _LLC_MOTIONFEEDBACK1_20_LLC_FBK_LONGITUDINALCONTROLMODETYPE,
    _LLC_MOTIONFEEDBACK1_20_LLC_FBK_STATETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1719,
  serialized_end=3580,
)


_LLC_MOTIONFEEDBACK2_21 = _descriptor.Descriptor(
  name='Llc_motionfeedback2_21',
  full_name='apollo.canbus.Llc_motionfeedback2_21',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='llc_fbk_vehiclespeed', full_name='apollo.canbus.Llc_motionfeedback2_21.llc_fbk_vehiclespeed', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_motionfeedback2_counter', full_name='apollo.canbus.Llc_motionfeedback2_21.llc_motionfeedback2_counter', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_motionfeedback2_checksum', full_name='apollo.canbus.Llc_motionfeedback2_21.llc_motionfeedback2_checksum', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_steeringrate', full_name='apollo.canbus.Llc_motionfeedback2_21.llc_fbk_steeringrate', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_steeringangle', full_name='apollo.canbus.Llc_motionfeedback2_21.llc_fbk_steeringangle', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3583,
  serialized_end=3773,
)


_LLC_MOTIONCOMMANDFEEDBACK1_22 = _descriptor.Descriptor(
  name='Llc_motioncommandfeedback1_22',
  full_name='apollo.canbus.Llc_motioncommandfeedback1_22',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='llc_fbk_steeringanglesetpoint', full_name='apollo.canbus.Llc_motioncommandfeedback1_22.llc_fbk_steeringanglesetpoint', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_throttlesetpoint', full_name='apollo.canbus.Llc_motioncommandfeedback1_22.llc_fbk_throttlesetpoint', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_brakepercentsetpoint', full_name='apollo.canbus.Llc_motioncommandfeedback1_22.llc_fbk_brakepercentsetpoint', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_motioncommandfeedback1_count', full_name='apollo.canbus.Llc_motioncommandfeedback1_22.llc_motioncommandfeedback1_count', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_motioncommandfeedback1_check', full_name='apollo.canbus.Llc_motioncommandfeedback1_22.llc_motioncommandfeedback1_check', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3776,
  serialized_end=4002,
)


_LLC_VEHICLESTATUS_25 = _descriptor.Descriptor(
  name='Llc_vehiclestatus_25',
  full_name='apollo.canbus.Llc_vehiclestatus_25',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='llc_fbk_12voltage', full_name='apollo.canbus.Llc_vehiclestatus_25.llc_fbk_12voltage', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4004,
  serialized_end=4053,
)


_LLC_AUXILIARYFEEDBACK_120 = _descriptor.Descriptor(
  name='Llc_auxiliaryfeedback_120',
  full_name='apollo.canbus.Llc_auxiliaryfeedback_120',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='llc_fbk_inverter', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_inverter', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_pdu_ch8', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_pdu_ch8', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_pdu_ch7', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_pdu_ch7', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_pdu_ch6', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_pdu_ch6', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_pdu_ch5', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_pdu_ch5', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_pdu_ch4', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_pdu_ch4', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_pdu_ch3', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_pdu_ch3', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_pdu_ch2', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_pdu_ch2', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_pdu_ch1', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_pdu_ch1', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_hazardlights', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_hazardlights', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_ledgreenon', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_ledgreenon', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_horn', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_horn', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_buzzeron', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_buzzeron', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_turnsignal', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_turnsignal', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_lowbeam', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_lowbeam', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_highbeam', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_highbeam', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_ledredon', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_ledredon', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_autonomybuttonpressed', full_name='apollo.canbus.Llc_auxiliaryfeedback_120.llc_fbk_autonomybuttonpressed', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LLC_AUXILIARYFEEDBACK_120_LLC_FBK_TURNSIGNALTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4056,
  serialized_end=4771,
)


_LLC_DIAG_FAULT_620 = _descriptor.Descriptor(
  name='Llc_diag_fault_620',
  full_name='apollo.canbus.Llc_diag_fault_620',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='llc_disengagecounter_brake', full_name='apollo.canbus.Llc_diag_fault_620.llc_disengagecounter_brake', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_disengagecounter_steer', full_name='apollo.canbus.Llc_diag_fault_620.llc_disengagecounter_steer', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_disengagecounter_throttle', full_name='apollo.canbus.Llc_diag_fault_620.llc_disengagecounter_throttle', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_faultcounter', full_name='apollo.canbus.Llc_diag_fault_620.llc_fbk_faultcounter', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_disengagecounter_button', full_name='apollo.canbus.Llc_diag_fault_620.llc_disengagecounter_button', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_version_year', full_name='apollo.canbus.Llc_diag_fault_620.llc_fbk_version_year', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_version_month', full_name='apollo.canbus.Llc_diag_fault_620.llc_fbk_version_month', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_version_day', full_name='apollo.canbus.Llc_diag_fault_620.llc_fbk_version_day', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_fbk_version_hour', full_name='apollo.canbus.Llc_diag_fault_620.llc_fbk_version_hour', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4774,
  serialized_end=5092,
)


_LLC_DIAG_STEERINGCONTROL_722 = _descriptor.Descriptor(
  name='Llc_diag_steeringcontrol_722',
  full_name='apollo.canbus.Llc_diag_steeringcontrol_722',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='llc_dbg_steeringsensorposition', full_name='apollo.canbus.Llc_diag_steeringcontrol_722.llc_dbg_steeringsensorposition', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_dbg_steeringrackinputtorque', full_name='apollo.canbus.Llc_diag_steeringcontrol_722.llc_dbg_steeringrackinputtorque', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_dbg_steeringmotorposition', full_name='apollo.canbus.Llc_diag_steeringcontrol_722.llc_dbg_steeringmotorposition', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5095,
  serialized_end=5245,
)


_ADC_AUXILIARYCONTROL_110 = _descriptor.Descriptor(
  name='Adc_auxiliarycontrol_110',
  full_name='apollo.canbus.Adc_auxiliarycontrol_110',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='adc_auxcontrol_counter', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_auxcontrol_counter', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_auxcontrol_checksum', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_auxcontrol_checksum', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_inverter_controlenable', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_inverter_controlenable', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_inverter', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_inverter', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_wiper', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_wiper', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_pdu_controlenable', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_pdu_controlenable', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_pdu_ch8', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_pdu_ch8', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_pdu_ch7', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_pdu_ch7', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_pdu_ch6', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_pdu_ch6', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_pdu_ch5', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_pdu_ch5', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_pdu_ch4', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_pdu_ch4', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_pdu_ch3', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_pdu_ch3', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_pdu_ch2', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_pdu_ch2', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_pdu_ch1', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_pdu_ch1', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_hazardlights', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_hazardlights', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_highbeam', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_highbeam', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_lowbeam', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_lowbeam', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_horn', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_horn', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_cmd_turnsignal', full_name='apollo.canbus.Adc_auxiliarycontrol_110.adc_cmd_turnsignal', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADC_AUXILIARYCONTROL_110_ADC_CMD_TURNSIGNALTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5248,
  serialized_end=6005,
)


_LLC_DIAG_BRAKECONTROL_721 = _descriptor.Descriptor(
  name='Llc_diag_brakecontrol_721',
  full_name='apollo.canbus.Llc_diag_brakecontrol_721',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='llc_dbg_brakepidcontribution_p', full_name='apollo.canbus.Llc_diag_brakecontrol_721.llc_dbg_brakepidcontribution_p', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_dbg_brakepidcontribution_i', full_name='apollo.canbus.Llc_diag_brakecontrol_721.llc_dbg_brakepidcontribution_i', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_dbg_brakepidcontribution_d', full_name='apollo.canbus.Llc_diag_brakecontrol_721.llc_dbg_brakepidcontribution_d', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_dbg_brakepid_output', full_name='apollo.canbus.Llc_diag_brakecontrol_721.llc_dbg_brakepid_output', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_dbg_brakepid_error', full_name='apollo.canbus.Llc_diag_brakecontrol_721.llc_dbg_brakepid_error', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_dbg_brakefeedforward', full_name='apollo.canbus.Llc_diag_brakecontrol_721.llc_dbg_brakefeedforward', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6008,
  serialized_end=6254,
)


_TRANSIT = _descriptor.Descriptor(
  name='Transit',
  full_name='apollo.canbus.Transit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='llc_vehiclelimits_24', full_name='apollo.canbus.Transit.llc_vehiclelimits_24', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_motioncontrol1_10', full_name='apollo.canbus.Transit.adc_motioncontrol1_10', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_motioncontrollimits1_12', full_name='apollo.canbus.Transit.adc_motioncontrollimits1_12', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_motionfeedback1_20', full_name='apollo.canbus.Transit.llc_motionfeedback1_20', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_motionfeedback2_21', full_name='apollo.canbus.Transit.llc_motionfeedback2_21', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_motioncommandfeedback1_22', full_name='apollo.canbus.Transit.llc_motioncommandfeedback1_22', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_vehiclestatus_25', full_name='apollo.canbus.Transit.llc_vehiclestatus_25', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_auxiliaryfeedback_120', full_name='apollo.canbus.Transit.llc_auxiliaryfeedback_120', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_diag_fault_620', full_name='apollo.canbus.Transit.llc_diag_fault_620', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_diag_steeringcontrol_722', full_name='apollo.canbus.Transit.llc_diag_steeringcontrol_722', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_auxiliarycontrol_110', full_name='apollo.canbus.Transit.adc_auxiliarycontrol_110', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llc_diag_brakecontrol_721', full_name='apollo.canbus.Transit.llc_diag_brakecontrol_721', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6257,
  serialized_end=7152,
)

_ADC_MOTIONCONTROL1_10.fields_by_name['adc_cmd_steeringcontrolmode'].enum_type = _ADC_MOTIONCONTROL1_10_ADC_CMD_STEERINGCONTROLMODETYPE
_ADC_MOTIONCONTROL1_10.fields_by_name['adc_cmd_gear'].enum_type = _ADC_MOTIONCONTROL1_10_ADC_CMD_GEARTYPE
_ADC_MOTIONCONTROL1_10.fields_by_name['adc_cmd_autonomyrequest'].enum_type = _ADC_MOTIONCONTROL1_10_ADC_CMD_AUTONOMYREQUESTTYPE
_ADC_MOTIONCONTROL1_10.fields_by_name['adc_cmd_longitudinalcontrolmode'].enum_type = _ADC_MOTIONCONTROL1_10_ADC_CMD_LONGITUDINALCONTROLMODETYPE
_ADC_MOTIONCONTROL1_10_ADC_CMD_STEERINGCONTROLMODETYPE.containing_type = _ADC_MOTIONCONTROL1_10
_ADC_MOTIONCONTROL1_10_ADC_CMD_GEARTYPE.containing_type = _ADC_MOTIONCONTROL1_10
_ADC_MOTIONCONTROL1_10_ADC_CMD_AUTONOMYREQUESTTYPE.containing_type = _ADC_MOTIONCONTROL1_10
_ADC_MOTIONCONTROL1_10_ADC_CMD_LONGITUDINALCONTROLMODETYPE.containing_type = _ADC_MOTIONCONTROL1_10
_LLC_MOTIONFEEDBACK1_20.fields_by_name['llc_fbk_gear'].enum_type = _LLC_MOTIONFEEDBACK1_20_LLC_FBK_GEARTYPE
_LLC_MOTIONFEEDBACK1_20.fields_by_name['llc_fbk_steeringcontrolmode'].enum_type = _LLC_MOTIONFEEDBACK1_20_LLC_FBK_STEERINGCONTROLMODETYPE
_LLC_MOTIONFEEDBACK1_20.fields_by_name['llc_fbk_longitudinalcontrolmode'].enum_type = _LLC_MOTIONFEEDBACK1_20_LLC_FBK_LONGITUDINALCONTROLMODETYPE
_LLC_MOTIONFEEDBACK1_20.fields_by_name['llc_fbk_state'].enum_type = _LLC_MOTIONFEEDBACK1_20_LLC_FBK_STATETYPE
_LLC_MOTIONFEEDBACK1_20_LLC_FBK_GEARTYPE.containing_type = _LLC_MOTIONFEEDBACK1_20
_LLC_MOTIONFEEDBACK1_20_LLC_FBK_STEERINGCONTROLMODETYPE.containing_type = _LLC_MOTIONFEEDBACK1_20
_LLC_MOTIONFEEDBACK1_20_LLC_FBK_LONGITUDINALCONTROLMODETYPE.containing_type = _LLC_MOTIONFEEDBACK1_20
_LLC_MOTIONFEEDBACK1_20_LLC_FBK_STATETYPE.containing_type = _LLC_MOTIONFEEDBACK1_20
_LLC_AUXILIARYFEEDBACK_120.fields_by_name['llc_fbk_turnsignal'].enum_type = _LLC_AUXILIARYFEEDBACK_120_LLC_FBK_TURNSIGNALTYPE
_LLC_AUXILIARYFEEDBACK_120_LLC_FBK_TURNSIGNALTYPE.containing_type = _LLC_AUXILIARYFEEDBACK_120
_ADC_AUXILIARYCONTROL_110.fields_by_name['adc_cmd_turnsignal'].enum_type = _ADC_AUXILIARYCONTROL_110_ADC_CMD_TURNSIGNALTYPE
_ADC_AUXILIARYCONTROL_110_ADC_CMD_TURNSIGNALTYPE.containing_type = _ADC_AUXILIARYCONTROL_110
_TRANSIT.fields_by_name['llc_vehiclelimits_24'].message_type = _LLC_VEHICLELIMITS_24
_TRANSIT.fields_by_name['adc_motioncontrol1_10'].message_type = _ADC_MOTIONCONTROL1_10
_TRANSIT.fields_by_name['adc_motioncontrollimits1_12'].message_type = _ADC_MOTIONCONTROLLIMITS1_12
_TRANSIT.fields_by_name['llc_motionfeedback1_20'].message_type = _LLC_MOTIONFEEDBACK1_20
_TRANSIT.fields_by_name['llc_motionfeedback2_21'].message_type = _LLC_MOTIONFEEDBACK2_21
_TRANSIT.fields_by_name['llc_motioncommandfeedback1_22'].message_type = _LLC_MOTIONCOMMANDFEEDBACK1_22
_TRANSIT.fields_by_name['llc_vehiclestatus_25'].message_type = _LLC_VEHICLESTATUS_25
_TRANSIT.fields_by_name['llc_auxiliaryfeedback_120'].message_type = _LLC_AUXILIARYFEEDBACK_120
_TRANSIT.fields_by_name['llc_diag_fault_620'].message_type = _LLC_DIAG_FAULT_620
_TRANSIT.fields_by_name['llc_diag_steeringcontrol_722'].message_type = _LLC_DIAG_STEERINGCONTROL_722
_TRANSIT.fields_by_name['adc_auxiliarycontrol_110'].message_type = _ADC_AUXILIARYCONTROL_110
_TRANSIT.fields_by_name['llc_diag_brakecontrol_721'].message_type = _LLC_DIAG_BRAKECONTROL_721
DESCRIPTOR.message_types_by_name['Llc_vehiclelimits_24'] = _LLC_VEHICLELIMITS_24
DESCRIPTOR.message_types_by_name['Adc_motioncontrol1_10'] = _ADC_MOTIONCONTROL1_10
DESCRIPTOR.message_types_by_name['Adc_motioncontrollimits1_12'] = _ADC_MOTIONCONTROLLIMITS1_12
DESCRIPTOR.message_types_by_name['Llc_motionfeedback1_20'] = _LLC_MOTIONFEEDBACK1_20
DESCRIPTOR.message_types_by_name['Llc_motionfeedback2_21'] = _LLC_MOTIONFEEDBACK2_21
DESCRIPTOR.message_types_by_name['Llc_motioncommandfeedback1_22'] = _LLC_MOTIONCOMMANDFEEDBACK1_22
DESCRIPTOR.message_types_by_name['Llc_vehiclestatus_25'] = _LLC_VEHICLESTATUS_25
DESCRIPTOR.message_types_by_name['Llc_auxiliaryfeedback_120'] = _LLC_AUXILIARYFEEDBACK_120
DESCRIPTOR.message_types_by_name['Llc_diag_fault_620'] = _LLC_DIAG_FAULT_620
DESCRIPTOR.message_types_by_name['Llc_diag_steeringcontrol_722'] = _LLC_DIAG_STEERINGCONTROL_722
DESCRIPTOR.message_types_by_name['Adc_auxiliarycontrol_110'] = _ADC_AUXILIARYCONTROL_110
DESCRIPTOR.message_types_by_name['Llc_diag_brakecontrol_721'] = _LLC_DIAG_BRAKECONTROL_721
DESCRIPTOR.message_types_by_name['Transit'] = _TRANSIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Llc_vehiclelimits_24 = _reflection.GeneratedProtocolMessageType('Llc_vehiclelimits_24', (_message.Message,), {
  'DESCRIPTOR' : _LLC_VEHICLELIMITS_24,
  '__module__' : 'modules.canbus.proto.transit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Llc_vehiclelimits_24)
  })
_sym_db.RegisterMessage(Llc_vehiclelimits_24)

Adc_motioncontrol1_10 = _reflection.GeneratedProtocolMessageType('Adc_motioncontrol1_10', (_message.Message,), {
  'DESCRIPTOR' : _ADC_MOTIONCONTROL1_10,
  '__module__' : 'modules.canbus.proto.transit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Adc_motioncontrol1_10)
  })
_sym_db.RegisterMessage(Adc_motioncontrol1_10)

Adc_motioncontrollimits1_12 = _reflection.GeneratedProtocolMessageType('Adc_motioncontrollimits1_12', (_message.Message,), {
  'DESCRIPTOR' : _ADC_MOTIONCONTROLLIMITS1_12,
  '__module__' : 'modules.canbus.proto.transit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Adc_motioncontrollimits1_12)
  })
_sym_db.RegisterMessage(Adc_motioncontrollimits1_12)

Llc_motionfeedback1_20 = _reflection.GeneratedProtocolMessageType('Llc_motionfeedback1_20', (_message.Message,), {
  'DESCRIPTOR' : _LLC_MOTIONFEEDBACK1_20,
  '__module__' : 'modules.canbus.proto.transit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Llc_motionfeedback1_20)
  })
_sym_db.RegisterMessage(Llc_motionfeedback1_20)

Llc_motionfeedback2_21 = _reflection.GeneratedProtocolMessageType('Llc_motionfeedback2_21', (_message.Message,), {
  'DESCRIPTOR' : _LLC_MOTIONFEEDBACK2_21,
  '__module__' : 'modules.canbus.proto.transit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Llc_motionfeedback2_21)
  })
_sym_db.RegisterMessage(Llc_motionfeedback2_21)

Llc_motioncommandfeedback1_22 = _reflection.GeneratedProtocolMessageType('Llc_motioncommandfeedback1_22', (_message.Message,), {
  'DESCRIPTOR' : _LLC_MOTIONCOMMANDFEEDBACK1_22,
  '__module__' : 'modules.canbus.proto.transit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Llc_motioncommandfeedback1_22)
  })
_sym_db.RegisterMessage(Llc_motioncommandfeedback1_22)

Llc_vehiclestatus_25 = _reflection.GeneratedProtocolMessageType('Llc_vehiclestatus_25', (_message.Message,), {
  'DESCRIPTOR' : _LLC_VEHICLESTATUS_25,
  '__module__' : 'modules.canbus.proto.transit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Llc_vehiclestatus_25)
  })
_sym_db.RegisterMessage(Llc_vehiclestatus_25)

Llc_auxiliaryfeedback_120 = _reflection.GeneratedProtocolMessageType('Llc_auxiliaryfeedback_120', (_message.Message,), {
  'DESCRIPTOR' : _LLC_AUXILIARYFEEDBACK_120,
  '__module__' : 'modules.canbus.proto.transit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Llc_auxiliaryfeedback_120)
  })
_sym_db.RegisterMessage(Llc_auxiliaryfeedback_120)

Llc_diag_fault_620 = _reflection.GeneratedProtocolMessageType('Llc_diag_fault_620', (_message.Message,), {
  'DESCRIPTOR' : _LLC_DIAG_FAULT_620,
  '__module__' : 'modules.canbus.proto.transit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Llc_diag_fault_620)
  })
_sym_db.RegisterMessage(Llc_diag_fault_620)

Llc_diag_steeringcontrol_722 = _reflection.GeneratedProtocolMessageType('Llc_diag_steeringcontrol_722', (_message.Message,), {
  'DESCRIPTOR' : _LLC_DIAG_STEERINGCONTROL_722,
  '__module__' : 'modules.canbus.proto.transit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Llc_diag_steeringcontrol_722)
  })
_sym_db.RegisterMessage(Llc_diag_steeringcontrol_722)

Adc_auxiliarycontrol_110 = _reflection.GeneratedProtocolMessageType('Adc_auxiliarycontrol_110', (_message.Message,), {
  'DESCRIPTOR' : _ADC_AUXILIARYCONTROL_110,
  '__module__' : 'modules.canbus.proto.transit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Adc_auxiliarycontrol_110)
  })
_sym_db.RegisterMessage(Adc_auxiliarycontrol_110)

Llc_diag_brakecontrol_721 = _reflection.GeneratedProtocolMessageType('Llc_diag_brakecontrol_721', (_message.Message,), {
  'DESCRIPTOR' : _LLC_DIAG_BRAKECONTROL_721,
  '__module__' : 'modules.canbus.proto.transit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Llc_diag_brakecontrol_721)
  })
_sym_db.RegisterMessage(Llc_diag_brakecontrol_721)

Transit = _reflection.GeneratedProtocolMessageType('Transit', (_message.Message,), {
  'DESCRIPTOR' : _TRANSIT,
  '__module__' : 'modules.canbus.proto.transit_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Transit)
  })
_sym_db.RegisterMessage(Transit)


# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python

# Copyright 2022 daohu527 <daohu527@gmail.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from record_msg.parser import to_csv


def test_to_csv():
  z = "1111"
  y = ['a', 'b', z]
  x = [1, 2, y]
  print(to_csv(x))

if __name__ == '__main__':
  test_to_csv()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/sl_boundary.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/sl_boundary.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(modules/planning/proto/sl_boundary.proto\x12\x0f\x61pollo.planning\x1a$modules/common/proto/pnc_point.proto\"|\n\nSLBoundary\x12\x0f\n\x07start_s\x18\x01 \x01(\x01\x12\r\n\x05\x65nd_s\x18\x02 \x01(\x01\x12\x0f\n\x07start_l\x18\x03 \x01(\x01\x12\r\n\x05\x65nd_l\x18\x04 \x01(\x01\x12.\n\x0e\x62oundary_point\x18\x05 \x03(\x0b\x32\x16.apollo.common.SLPoint'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,])




_SLBOUNDARY = _descriptor.Descriptor(
  name='SLBoundary',
  full_name='apollo.planning.SLBoundary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_s', full_name='apollo.planning.SLBoundary.start_s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_s', full_name='apollo.planning.SLBoundary.end_s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_l', full_name='apollo.planning.SLBoundary.start_l', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_l', full_name='apollo.planning.SLBoundary.end_l', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boundary_point', full_name='apollo.planning.SLBoundary.boundary_point', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=223,
)

_SLBOUNDARY.fields_by_name['boundary_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._SLPOINT
DESCRIPTOR.message_types_by_name['SLBoundary'] = _SLBOUNDARY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SLBoundary = _reflection.GeneratedProtocolMessageType('SLBoundary', (_message.Message,), {
  'DESCRIPTOR' : _SLBOUNDARY,
  '__module__' : 'modules.planning.proto.sl_boundary_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.SLBoundary)
  })
_sym_db.RegisterMessage(SLBoundary)


# @@protoc_insertion_point(module_scope)
